warn_if_pg_scram_disabled

Function warn_if_pg_scram_disabled 

pub(crate) fn warn_if_pg_scram_disabled(
    users: &HashMap<String, (PasswordVerifier, PermissionMode)>,
)
Warns once per credential load when the set disables Postgres SCRAM, so operators don’t unknowingly serve cleartext passwords over Postgres while believing SCRAM is in effect.